@@ -3,11 +3,11 @@
 
 [![npm version](https://badge.fury.io/js/%40nomadblacky%2Fcdk-datadog-resources.svg)](https://badge.fury.io/js/%40nomadblacky%2Fcdk-datadog-resources)
 
-An AWS CDK construct library that wrapped [DataDog/datadog-cloudformation-resources](https://github.com/DataDog/datadog-cloudformation-resources).
+An AWS CDK construct library that wraps [DataDog/datadog-cloudformation-resources](https://github.com/DataDog/datadog-cloudformation-resources).
 
 ## Requirements
 
-Before use this library, [register datadog-cloudformation-resources to your AWS account.](https://github.com/DataDog/datadog-cloudformation-resources#datadog-aws-cloudformation)
+Before using this library, [register datadog-cloudformation-resources to your AWS account.](https://github.com/DataDog/datadog-cloudformation-resources#datadog-aws-cloudformation)
 
 You need to register the correct version listed in `Supported Resources`.
 
@@ -22,7 +22,7 @@ You need to register the correct version listed in `Supported Resources`.
 | Supported? | Resource                | Datadog CF Resource Name         | Description                                              | Datadog CF Version |
 | :--------: | ----------------------- | -------------------------------- | -------------------------------------------------------- | ------------------ |
 |     ✅     | Dashboards              | `Datadog::Dashboards::Dashboard` | [Create, update, and delete Datadog dashboards.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-dashboards-dashboard-handler)      | [1.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-dashboards-dashboard-handler/CHANGELOG.md#100--2021-02-16)         |
-|            | Datadog-AWS integration | `Datadog::Integrations::AWS`     | [Manage your Datadog-Amazon Web Service integration.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-integrations-aws-handler) | N/A                |
+|     ✅     | Datadog-AWS integration | `Datadog::Integrations::AWS`     | [Manage your Datadog-Amazon Web Service integration.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-integrations-aws-handler) | [1.1.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-integrations-aws-handler/CHANGELOG.md#110--2020-08-04)        |
 |     ✅     | Monitors                | `Datadog::Monitors::Monitor`     | [Create, update, and delete Datadog monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-monitor-handler)        | [3.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-monitor-handler/CHANGELOG.md#300--2021-02-16)         |
 |     ✅     | Downtimes               | `Datadog::Monitors::Downtime`    | [Enable or disable downtimes for your monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-downtime-handler)      | [2.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-downtime-handler/CHANGELOG.md#200--2021-02-16)         |
 |     ✅     | Users                   | `Datadog::IAM::User`             | [Create and manage Datadog users.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-iam-user-handler)                    | [1.2.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-iam-user-handler/CHANGELOG.md#120--2021-02-16)         |
@@ -53,7 +53,7 @@ Java
 
 ## Usage
 
-Belows are examples of TypeScript.
+Below are examples of TypeScript.
 
 ### Dashboards
 
@@ -131,6 +131,20 @@ DatadogIAMUser(stack, "TestUser",
     disabled=False
 )
 ```
+
+### DataDog Integration
+
+```python
+# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
+DatadogIntegration(self, "DataDogIntegration",
+    datadog_credentials={
+        "api_key": "DATADOG_API_KEY",
+        "application_key": "DATADOG_APP_KEY"
+    },
+    account_id="ACCOUNT_ID",
+    role_name="DatadogIntegrationRole"
+)
+```
 '''
 import abc
 import builtins
@@ -727,6 +741,100 @@ class DatadogIAMUserProps:
         )
 
 
+class DatadogIntegrationAWS(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogIntegrationAWS",
+):
+    '''Datadog Integration 1.1.0.'''
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: builtins.str,
+        *,
+        account_id: builtins.str,
+        datadog_credentials: DatadogCredentials,
+        role_name: builtins.str,
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param account_id: The id of the account with which to integrate.
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param role_name: The name of the created role.
+        '''
+        props = DatadogIntegrationAWSProps(
+            account_id=account_id,
+            datadog_credentials=datadog_credentials,
+            role_name=role_name,
+        )
+
+        jsii.create(self.__class__, self, [scope, id, props])
+
+
+@jsii.data_type(
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogIntegrationAWSProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "account_id": "accountId",
+        "datadog_credentials": "datadogCredentials",
+        "role_name": "roleName",
+    },
+)
+class DatadogIntegrationAWSProps:
+    def __init__(
+        self,
+        *,
+        account_id: builtins.str,
+        datadog_credentials: DatadogCredentials,
+        role_name: builtins.str,
+    ) -> None:
+        '''
+        :param account_id: The id of the account with which to integrate.
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param role_name: The name of the created role.
+        '''
+        if isinstance(datadog_credentials, dict):
+            datadog_credentials = DatadogCredentials(**datadog_credentials)
+        self._values: typing.Dict[str, typing.Any] = {
+            "account_id": account_id,
+            "datadog_credentials": datadog_credentials,
+            "role_name": role_name,
+        }
+
+    @builtins.property
+    def account_id(self) -> builtins.str:
+        '''The id of the account with which to integrate.'''
+        result = self._values.get("account_id")
+        assert result is not None, "Required property 'account_id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def datadog_credentials(self) -> DatadogCredentials:
+        '''Credentials for the Datadog API.'''
+        result = self._values.get("datadog_credentials")
+        assert result is not None, "Required property 'datadog_credentials' is missing"
+        return typing.cast(DatadogCredentials, result)
+
+    @builtins.property
+    def role_name(self) -> builtins.str:
+        '''The name of the created role.'''
+        result = self._values.get("role_name")
+        assert result is not None, "Required property 'role_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "DatadogIntegrationAWSProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class DatadogMonitor(
     metaclass=jsii.JSIIMeta,
     jsii_type="@nomadblacky/cdk-datadog-resources.DatadogMonitor",
@@ -1254,6 +1362,8 @@ __all__ = [
     "DatadogDowntimeProps",
     "DatadogIAMUser",
     "DatadogIAMUserProps",
+    "DatadogIntegrationAWS",
+    "DatadogIntegrationAWSProps",
     "DatadogMonitor",
     "DatadogMonitorProps",
     "MonitorOptions",
